==> sagemaker-0.21.0-sources.jar: software/amazon/awscdk/services/sagemaker/CfnNotebookInstance.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstance.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:28:27.680Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sagemaker.$Module.class, fqn = "@aws-cdk/aws-sagemaker.CfnNotebookInstance")
public class CfnNotebookInstance extends software.amazon.awscdk.Resource {
    protected CfnNotebookInstance(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.sagemaker.CfnNotebookInstance.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::SageMaker::NotebookInstance``.
     * @param parent the ``cdk.Construct`` this ``CfnNotebookInstance`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CfnNotebookInstance``
     */
    public CfnNotebookInstance(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getNotebookInstanceArn() {
        return this.jsiiGet("notebookInstanceArn", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute NotebookInstanceName
     */
    public java.lang.String getNotebookInstanceName() {
        return this.jsiiGet("notebookInstanceName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps.class);
    }
}

==> sagemaker-0.23.0-sources.jar: software/amazon/awscdk/services/sagemaker/CfnNotebookInstance.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstance.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.14 (build 91853ce)", date = "2019-02-04T14:51:32.907Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sagemaker.$Module.class, fqn = "@aws-cdk/aws-sagemaker.CfnNotebookInstance")
public class CfnNotebookInstance extends software.amazon.awscdk.Resource {
    protected CfnNotebookInstance(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.sagemaker.CfnNotebookInstance.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::SageMaker::NotebookInstance``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnNotebookInstance(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getNotebookInstanceArn() {
        return this.jsiiGet("notebookInstanceArn", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute NotebookInstanceName
     */
    public java.lang.String getNotebookInstanceName() {
        return this.jsiiGet("notebookInstanceName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.sagemaker.CfnNotebookInstanceProps.class);
    }
}
